(function ($) {
    'use strict';

    /**
     * All of the code for your admin-facing JavaScript source
     * should reside in this file.
     *
     * Note: It has been assumed you will write jQuery code here, so the
     * $ function reference has been prepared for usage within the scope
     * of this function.
     *
     * This enables you to define handlers, for when the DOM is ready:
     *
     * $(function() {
     *
     * });
     *
     * When the window is loaded:
     *
     * $( window ).load(function() {
     *
     * });
     *
     * ...and/or other possibilities.
     *
     * Ideally, it is not considered best practise to attach more than a
     * single DOM-ready or window-load handler for a particular page.
     * Although scripts in the WordPress core, Plugins and Themes may be
     * practising this, we should strive to set a better example in our own work.
     * 
     */
    $(document).ready(function () {
        // only load the scripts we need for the page we're on
        switch ($('#sgc_javascript').val()) {
            case 'sgc_scorecard' :
                let scorecardclass = new SGC_Scorecard();
                
                $('div[id=titlewrap]').hide();					// Hide Title
                $('div[id=postdivrich]').hide();				// Hide Content 
                $('div[id=minor-publishing-actions]').hide();			// Hide Draft & preview buttons

                $('form').each(scorecardclass.load_scorecard);			// Load score from the content box into the scorecard

                $("#publish").click(scorecardclass.publish_hook);		// Attach to the "Publish" button and automatically fill in fields
                $("#sgc_scorecardevent").change(scorecardclass.event_list_change);	// Actions to perform when manipulating the score card event drop down menu
                $("#sgc_scorecardplayer").change(scorecardclass.player_list_change);	// Actions to perform when manipulating the score card player drop down menu

                break;
            case 'sgc_event' :
                let eventclass = new SGC_Event();
                
                $('#sgc_eventteam').change(eventclass.update_player_list);      // bind to the team list and update the player list when it changes
                $('#sgc_managegroups').click(eventclass.manage_group);		// bind to the manage groups button click event
                $('#sgc_event_groupadd').click(eventclass.add_group);        	// bind to the groupadd button click event
                $('#sgc_event_groupdel').click(eventclass.del_group);        	// bind to the delete group click event
                $('#sgc_event_groupsave').click(eventclass.save_groups);	// bind to the group save button
                break;
            case 'sgc_location' :
                let locationclass = new SGC_Location();
                
                $('form').each(locationclass.load_course);                      //load the course information.
                $("#publish").click(locationclass.publish_hook);                // attach to the "Publish" button 
                break;
        }
    });

})(jQuery);
